# Table of Contents

- [cookies-and-local-storage-policy-sap-leanix-workspace](<./cookies-and-local-storage-policy-sap-leanix-workspace.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Cookies and Local Storage Policy: SAP LeanIX Workspace](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace.md>)
  - [1. Purpose and scope](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/1.-Purpose-and-scope.md>)
  - [2. What is a cookie?](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/2.-What-is-a-cookie.md>)
  - [3. What is a local storage object?](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/3.-What-is-a-local-storage-object.md>)
  - [4. Types of cookies and local storage objects used in SAP LeanIX Workspaces](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/4.-Types-of-cookies-and-local-storage-objects-used-in-SAP-LeanIX-Workspaces.md>)
  - [4.1 List of cookies and local storage objects](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/4.1-List-of-cookies-and-local-storage-objects.md>)
  - [5. How to block or delete cookies and local storage objects](<./Cookies-and-Local-Storage-Policy-SAP-LeanIX-Workspace/5.-How-to-block-or-delete-cookies-and-local-storage-objects.md>)
